@@ -2,11 +2,11 @@
 // This file is part of the gmod package
 // Copyright (C) 1997 by Andrew J. Robinson
 
-#ifndef __CommentShell_h
-#define __CommentShell_h
+#ifndef __CommentShellH
+#define __CommentShellH
 
 #include <qapp.h>
-#include <qlabel.h>
+#include <qmlined.h>
 #include <qpushbt.h>
 
 class CommentShell : public QWidget
@@ -14,7 +14,7 @@ class CommentShell : public QWidget
   Q_OBJECT
 public:
   CommentShell(QWidget *w = 0);
-  void setComment(const char *text);
+  void setComment(char *, int);
 
  public slots:
  void showCommentShell();
@@ -23,17 +23,12 @@ protected:
   void resizeEvent(QResizeEvent *);
 
 private:
-  QLabel *commentLabel;
+  QMultiLineEdit *commentEdit;
   QPushButton *closeButton;
 
  private slots:
  void closeCommentShell();
 };
 
-inline void
-CommentShell::setComment(const char *text)
-{
-  commentLabel->setText(text);
-}
 
 #endif
