@@ -8,6 +8,7 @@
 #ifdef USE_NCURSES
 #include <curses.h>
 #else
+#include <stdio.h>
 #include <termios.h>
 #endif
 
@@ -19,32 +20,24 @@ public:
   CursesScr(unsigned char);
   ~CursesScr();
 
-  void setFile(char *);
-  void setInfo(char *, char *, char *, unsigned char, unsigned int, short);
-  void setSamples(Sample *[], unsigned int, unsigned char);
+  void moduleFile(const char *);
+  void moduleTitle(const char *);
+  void setChannels(int);
+  void setType(const char *);
+  void setMaxPosition(int);
   void setMem(int, int);
   void setPos(unsigned int, unsigned int);
   int getChar();
 
-#ifdef USE_NCURSES
-  void scrollSamples(int);
-#endif
-
 private:
   unsigned char background_;
 #ifdef USE_NCURSES
-  int sampleLines_;
-  unsigned int nrSamples_;
-  unsigned char showEmpty_;
-  int firstVisible_;
-
   WINDOW *infoWin;
-  WINDOW *sampleWin;
   WINDOW *memWin;
   WINDOW *posWin;
 #else
-  long old_flags_;
-  struct termios old_termio_;
+  long oldFlags_;
+  struct termios oldTermio_;
 #endif
 };
 
