@@ -2,8 +2,8 @@
 // This file is part of the gmod package
 // Copyright (C) 1997 by Andrew J. Robinson
 
-#ifndef __Envelope_h
-#define __Envelope_h
+#ifndef __EnvelopeH
+#define __EnvelopeH
 
 struct EnvelopeSegment
 {
@@ -18,12 +18,12 @@ class Envelope
 public:
   Envelope();
   ~Envelope();
-  void load(int, int, int, int, int, unsigned short, unsigned char *);
-  int getY(int &, unsigned short &, char) const;
-  int enabled() const;
+  void load(int, int, int, int, int, unsigned short, int, unsigned char *);
+  int getY(int &, char, unsigned short * = 0) const;
 
 private:
   struct EnvelopeSegment *envelope;
+  int baseValue_;
   int numSegments;
   int sustainX;
   int loopOn;
@@ -46,10 +46,4 @@ Envelope::~Envelope()
     delete [] envelope;
 }
 
-inline int
-Envelope::enabled() const
-{
-  return ((numSegments != 0) || (fadeRate));
-}
-
 #endif
