@@ -2,8 +2,8 @@
 // This file is part of the gmod package
 // Copyright (C) 1997 by Andrew J. Robinson
 
-#ifndef __QueueShell_h
-#define __QueueShell_h
+#ifndef __QueueShellH
+#define __QueueShellH
 
 #include <qapp.h>
 #undef Unsorted
@@ -14,7 +14,7 @@
 
 class TopShell;
 
-struct q_info_array
+struct qInfoArray
 {
   char *name, *label;
   int x, y, width, height;
@@ -54,13 +54,13 @@ protected:
   void resizeEvent(QResizeEvent *);
 
 private:
-  void add_module(int, const char *);
+  void addModule(int, const char *);
   QListBox *queueList;
   QPushButton *buttons[8];
   QFileDialog *saveDialog;
   XQFileDialog *loadDialog;
 
-  static struct q_info_array button_info[8];
+  static struct qInfoArray buttonInfo[8];
 
  private slots:
  void showQueueShell();
