@@ -2,8 +2,8 @@
 // This file is part of the gmod package
 // Copyright (C) 1997 by Andrew J. Robinson
 
-#ifndef __TrackShell_h
-#define __TrackShell_h
+#ifndef __TrackShellH
+#define __TrackShellH
 
 #include <qapp.h>
 #include <qlistbox.h>
@@ -20,7 +20,7 @@ public:
   void insertLine(const char *);
   void setCurrent(int);
   void updateTracker(int, int, short [MAX_POSITION][MAX_TRACK],
-		     struct note_info *[MAX_PATTERN * MAX_TRACK]);
+		     struct noteInfo *[MAX_PATTERN * MAX_TRACK]);
 
  public slots:
  void showTrackShell();
