@@ -2,8 +2,8 @@
 // This file is part of the gmod package
 // Copyright (C) 1997 by Andrew J. Robinson
 
-#ifndef mod_h
-#define mod_h
+#ifndef modH
+#define modH
 
 #include "Sample.h"
 
