@@ -2,8 +2,8 @@
 // This file is part of the gmod package
 // Copyright (C) 1997 by Andrew J. Robinson
 
-#ifndef mtm_h
-#define mtm_h
+#ifndef mtmH
+#define mtmH
 
 #include "Sample.h"
 
