@@ -2,8 +2,8 @@
 // This file is part of the gmod package
 // Copyright (C) 1997 by Andrew J. Robinson
 
-#ifndef s3m_h
-#define s3m_h
+#ifndef s3mH
+#define s3mH
 
 #include "Sample.h"
 
@@ -11,14 +11,14 @@ class S3M_sample : public Sample
 {
 public:
   int load(Sequencer &, FILE *, int, int, void *, void *);
-  int slide_rate(int, unsigned char) const;
+  int slideRate(int, unsigned char) const;
 };
 
 inline int
-S3M_sample::slide_rate(int rate, unsigned char slide_dir) const
+S3M_sample::slideRate(int rate, unsigned char slideDir) const
 {
-   return ((int)(double(Sample::slide_rate(rate, slide_dir)) *
-		 (_base_freq / 8363.0)));
+   return ((int)(double(Sample::slideRate(rate, slideDir)) *
+		 (baseFreq_ / 8363.0)));
 }
 
 #endif
