@@ -2,8 +2,8 @@
 // This file is part of the gmod package
 // Copyright (C) 1997 by Andrew J. Robinson
 
-#ifndef ult_h
-#define ult_h
+#ifndef ultH
+#define ultH
 
 #include "Sample.h"
 
